==> react-daily-components-0.4.9.tgz: package/lib/esm/components/inputs/Select/style.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import styled from "@emotion/styled";
import { ELLIPSIS, OUT_SHADOW } from "../../../constants/css";
import { ContainerBase } from "../../base/ContainerBase";
import { InputEllipsisBase } from "../../base/InputBase";
import { ItemBase } from "../../base/ItemBase";
import { ListBase } from "../../../components/base/ListBase";
export var Container = styled(ContainerBase)(templateObject_1 || (templateObject_1 = __makeTemplateObject([""], [""])));
export var Input = styled(InputEllipsisBase)(templateObject_2 || (templateObject_2 = __makeTemplateObject([""], [""])));
export var List = styled(ListBase)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  color: ", ";\n  max-height: ", ";\n  overflow-y: auto;\n  width: 100%;\n  top: 55px;\n  border-radius: 4px;\n  box-shadow: ", ";\n"], ["\n  color: ", ";\n  max-height: ", ";\n  overflow-y: auto;\n  width: 100%;\n  top: 55px;\n  border-radius: 4px;\n  box-shadow: ", ";\n"])), function (_a) {
    var _b;
    var theme = _a.theme;
    return (_b = theme.defaultColor) !== null && _b !== void 0 ? _b : "gray";
}, function (_a) {
    var itemHeight = _a.itemHeight, showItemCount = _a.showItemCount;
    return "calc(".concat(itemHeight, " * ").concat(showItemCount, ")");
}, OUT_SHADOW);
export var Option = styled.option(templateObject_4 || (templateObject_4 = __makeTemplateObject([""], [""])));
export var Item = styled(ItemBase)(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  height: 35px;\n  line-height: 35px;\n  padding: 0 10px;\n  ", ";\n"], ["\n  height: 35px;\n  line-height: 35px;\n  padding: 0 10px;\n  ", ";\n"])), ELLIPSIS);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5;

==> react-daily-components-0.5.3.tgz: package/lib/esm/components/inputs/Select/style.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import styled from "@emotion/styled";
import { ELLIPSIS } from "../../../constants/css";
import { ContainerBase } from "../../base/ContainerBase";
import { InputEllipsisBase } from "../../base/InputBase";
import { ItemBase } from "../../base/ItemBase";
import { ListBase } from "../../../components/base/ListBase";
export var Container = styled(ContainerBase)(templateObject_1 || (templateObject_1 = __makeTemplateObject([""], [""])));
export var Input = styled(InputEllipsisBase)(templateObject_2 || (templateObject_2 = __makeTemplateObject([""], [""])));
export var List = styled(ListBase)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  color: ", ";\n  max-height: ", ";\n  overflow-y: auto;\n  top: 55px;\n"], ["\n  color: ", ";\n  max-height: ", ";\n  overflow-y: auto;\n  top: 55px;\n"])), function (_a) {
    var _b;
    var theme = _a.theme;
    return (_b = theme.defaultColor) !== null && _b !== void 0 ? _b : "gray";
}, function (_a) {
    var itemHeight = _a.itemHeight, showItemCount = _a.showItemCount;
    return "calc(".concat(itemHeight, " * ").concat(showItemCount, ")");
});
export var Option = styled.option(templateObject_4 || (templateObject_4 = __makeTemplateObject([""], [""])));
export var Item = styled(ItemBase)(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  ", ";\n"], ["\n  ", ";\n"])), ELLIPSIS);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5;
